library datalandingpage_devaloop_com;

import 'dart:async';

import 'package:flutter/material.dart';

class DataLandingPage extends StatefulWidget {
  final String dataTitle;
  final Future<List<ListTile>> showLatest;
  final Future<int> totalData;
  final Future<int>? addedToday;
  final Future<int>? updatedToday;
  final Widget? drawer;
  final Function()? searchClick;
  final Function()? addClick;
  final Function()? refreshClick;

  const DataLandingPage({
    super.key,
    required this.dataTitle,
    required this.showLatest,
    required this.totalData,
    this.drawer,
    this.addedToday,
    this.updatedToday,
    this.searchClick,
    this.addClick,
    this.refreshClick,
  });

  @override
  DataLandingPageState createState() {
    return DataLandingPageState();
  }
}

class DataLandingPageState extends State<DataLandingPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var appBar = AppBar(
      title: Text(widget.dataTitle),
      actions: [
        if (widget.searchClick != null)
          IconButton(
            icon: const Icon(Icons.search),
            tooltip: 'Search',
            onPressed: widget.searchClick,
          ),
        if (widget.addClick != null)
          IconButton(
            icon: const Icon(Icons.add),
            tooltip: 'Add',
            onPressed: widget.addClick,
          ),
        if (widget.refreshClick != null)
          IconButton(
            icon: const Icon(Icons.refresh),
            tooltip: 'Refresh',
            onPressed: widget.refreshClick,
          ),
      ],
    );
    var summaryData = [
      Expanded(
        child: Center(
          child: FutureBuilder(
            future: widget.totalData,
            builder: (context, snapshot) {
              if (snapshot.connectionState == ConnectionState.waiting) {
                return const Column(
                  children: [
                    Expanded(
                      child: Align(
                        alignment: Alignment.bottomCenter,
                        child: CircularProgressIndicator(),
                      ),
                    ),
                    Expanded(
                      child: Padding(
                        padding: EdgeInsets.only(
                          top: 15,
                        ),
                        child: Text(
                          "Total",
                          style: TextStyle(
                            color: Colors.black54,
                          ),
                        ),
                      ),
                    ),
                  ],
                );
              } else if (snapshot.hasError) {
                return const Column(
                  children: [
                    Expanded(
                      child: Align(
                        alignment: Alignment.bottomCenter,
                        child: CircularProgressIndicator(),
                      ),
                    ),
                    Expanded(
                      child: Padding(
                        padding: EdgeInsets.only(
                          top: 15,
                        ),
                        child: Text(
                          "Total",
                          style: TextStyle(
                            color: Colors.black54,
                          ),
                        ),
                      ),
                    ),
                  ],
                );
              } else {
                final data = snapshot.data ?? 0;

                return RichText(
                  textAlign: TextAlign.center,
                  text: TextSpan(
                    children: [
                      TextSpan(
                        text: data.toString(),
                        style: const TextStyle(
                          color: Colors.black87,
                          fontSize: 20,
                        ),
                      ),
                      const TextSpan(
                        text: '\nTotal',
                        style: TextStyle(
                          color: Colors.black54,
                        ),
                      ),
                    ],
                  ),
                );
              }
            },
          ),
        ),
      ),
      if (widget.addedToday != null)
        Expanded(
          child: Center(
            child: FutureBuilder(
              future: widget.addedToday,
              builder: (context, snapshot) {
                if (snapshot.connectionState == ConnectionState.waiting) {
                  return const Column(
                    children: [
                      Expanded(
                        child: Align(
                          alignment: Alignment.bottomCenter,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                      Expanded(
                        child: Padding(
                          padding: EdgeInsets.only(
                            top: 15,
                          ),
                          child: Text(
                            "Added Today",
                            style: TextStyle(
                              color: Colors.black54,
                            ),
                          ),
                        ),
                      ),
                    ],
                  );
                } else if (snapshot.hasError) {
                  return const Column(
                    children: [
                      Expanded(
                        child: Align(
                          alignment: Alignment.bottomCenter,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                      Expanded(
                        child: Padding(
                          padding: EdgeInsets.only(
                            top: 15,
                          ),
                          child: Text(
                            "Added Today",
                            style: TextStyle(
                              color: Colors.black54,
                            ),
                          ),
                        ),
                      ),
                    ],
                  );
                } else {
                  final data = snapshot.data ?? 0;

                  return RichText(
                    textAlign: TextAlign.center,
                    text: TextSpan(
                      children: [
                        TextSpan(
                          text: data.toString(),
                          style: const TextStyle(
                            color: Colors.black87,
                            fontSize: 20,
                          ),
                        ),
                        const TextSpan(
                          text: '\nAdded Today',
                          style: TextStyle(
                            color: Colors.black54,
                          ),
                        ),
                      ],
                    ),
                  );
                }
              },
            ),
          ),
        ),
      if (widget.updatedToday != null)
        Expanded(
          child: Center(
            child: FutureBuilder(
              future: widget.updatedToday,
              builder: (context, snapshot) {
                if (snapshot.connectionState == ConnectionState.waiting) {
                  return const Column(
                    children: [
                      Expanded(
                        child: Align(
                          alignment: Alignment.bottomCenter,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                      Expanded(
                        child: Padding(
                          padding: EdgeInsets.only(
                            top: 15,
                          ),
                          child: Text(
                            "Updated Today",
                            style: TextStyle(
                              color: Colors.black54,
                            ),
                          ),
                        ),
                      ),
                    ],
                  );
                } else if (snapshot.hasError) {
                  return const Column(
                    children: [
                      Expanded(
                        child: Align(
                          alignment: Alignment.bottomCenter,
                          child: CircularProgressIndicator(),
                        ),
                      ),
                      Expanded(
                        child: Padding(
                          padding: EdgeInsets.only(
                            top: 15,
                          ),
                          child: Text(
                            "Updated Today",
                            style: TextStyle(
                              color: Colors.black54,
                            ),
                          ),
                        ),
                      ),
                    ],
                  );
                } else {
                  final data = snapshot.data ?? 0;

                  return RichText(
                    textAlign: TextAlign.center,
                    text: TextSpan(
                      children: [
                        TextSpan(
                          text: data.toString(),
                          style: const TextStyle(
                            color: Colors.black87,
                            fontSize: 20,
                          ),
                        ),
                        const TextSpan(
                          text: '\nUpdated Today',
                          style: TextStyle(
                            color: Colors.black54,
                          ),
                        ),
                      ],
                    ),
                  );
                }
              },
            ),
          ),
        ),
    ];

    var showLatestData = Expanded(
      child: Padding(
        padding: const EdgeInsets.only(
          top: 20,
          bottom: 20,
          left: 10,
          right: 10,
        ),
        child: FutureBuilder(
          future: widget.showLatest,
          builder: (context, snapshot) {
            if (snapshot.connectionState == ConnectionState.waiting) {
              return const Column(
                children: [
                  Expanded(
                    child: Align(
                      alignment: Alignment.bottomCenter,
                      child: CircularProgressIndicator(),
                    ),
                  ),
                  Expanded(
                    child: Padding(
                      padding: EdgeInsets.only(
                        top: 15,
                      ),
                      child: Text(
                        "Show Latest",
                        style: TextStyle(
                          color: Colors.black54,
                        ),
                      ),
                    ),
                  ),
                ],
              );
            } else if (snapshot.hasError) {
              return const Column(
                children: [
                  Expanded(
                    child: Align(
                      alignment: Alignment.bottomCenter,
                      child: CircularProgressIndicator(),
                    ),
                  ),
                  Expanded(
                    child: Padding(
                      padding: EdgeInsets.only(
                        top: 15,
                      ),
                      child: Text(
                        "Show Latest",
                        style: TextStyle(
                          color: Colors.black54,
                        ),
                      ),
                    ),
                  ),
                ],
              );
            } else {
              final data = snapshot.data ?? <ListTile>[];

              return Column(
                children: [
                  Padding(
                    padding: const EdgeInsets.only(
                      top: 0,
                      bottom: 10,
                      left: 10,
                      right: 10,
                    ),
                    child: Align(
                      alignment: Alignment.topLeft,
                      child: Text(
                          'Show top ${data.length.toString()} latest data.'),
                    ),
                  ),
                  Expanded(
                    child: data.isNotEmpty
                        ? ListView.separated(
                            itemBuilder: (context, index) {
                              return data[index];
                            },
                            separatorBuilder: (context, index) =>
                                const Divider(),
                            itemCount: data.length,
                            shrinkWrap: true,
                          )
                        : const Center(
                            child: Text(
                              "No data",
                              style: TextStyle(
                                color: Colors.black54,
                              ),
                            ),
                          ),
                  ),
                ],
              );
            }
          },
        ),
      ),
    );

    return Scaffold(
      appBar: appBar,
      drawer: widget.drawer,
      body: Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(10),
        ),
        color: Colors.white,
        margin: const EdgeInsets.only(
          left: 10,
          right: 10,
          top: 0,
          bottom: 10,
        ),
        child: MediaQuery.of(context).orientation == Orientation.landscape
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(10),
                    child: SizedBox(
                      width: 100,
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: summaryData,
                      ),
                    ),
                  ),
                  const VerticalDivider(),
                  showLatestData,
                ],
              )
            : Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(10),
                    child: SizedBox(
                      height: 100,
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: summaryData,
                      ),
                    ),
                  ),
                  const Divider(
                    height: 1,
                  ),
                  showLatestData,
                ],
              ),
      ),
    );
  }
}
